import java.io.*;
import java.net.*;
import java.sql.*;
import java.util.*;
import java.util.Date;

/**
 * Die Klasse <var>Database</var> reprsentiert eine
 * Datenbankverbindung. 
 * <p>
 * Bei dem Instantieren der Klasse werden ber den Konstruktor die 
 * notwendigen Parameter bergeben.  
 * </p>
 * @author Sven Garske und Jrn Hauswald
 * @verison Projektstudium SS98
 */


public class Database
{
   Connection con;
   Statement stmt;

   PreparedStatement pstmt;

   Date datum;
   String name;
   String gruppe;
   String beschr;
   String std;
  
   String sql;
   

/**
  * Default-Konstruktor fr normales Statement
  */
  Database(Connection con,String sql) throws SQLException {
      this.con = con;
      stmt = con.createStatement();
      pstmt=null;
      this.sql=sql;
   }/* default-Konstruktor */


/**
  * Konstruktor fr PreparedStatement
  */
  Database(Connection con,Date datum,String name,String gruppe,String beschr,String std) throws SQLException {
      this.con = con;
      this.datum=datum;
      this.name=name;
      this.gruppe=gruppe;
      this.beschr=beschr;
      this.std=std; 
  
      
     //Verwendung von der Escape-Syntax, weil Typkonflikt
      String sql="Insert into protokoll values ({d '"+datum+"'},?,?,?,?)";    
   
      pstmt=con.prepareStatement(sql);     

   }/* default-Konstruktor */


/** 
  * liefert das Ergebnis einer Statement-Anfrage
  * @exception SQLException ausgelst bei Fehler in SQL-Statement
  * @return Ergebnis einer SQL-Anfrage ueber SQL-Statement
  */
  protected ResultSet execSQL() throws SQLException {
   
      /* Statement erzeugen, falls ntig: */
	 if (stmt == null)
	    stmt = con.createStatement();

      /* SELECT-Anweisung ausfhren: */
         return stmt.executeQuery(sql); 
  }/* execSQL() */


/**
  * Setzen der Parameter des PreparedStatements
  * @exception SQLException ausgelst bei Fehler in SQL-Statement
  */
  protected void execPreparedStmt() throws SQLException {
             
   //Parameter setzen
     pstmt.setString(1,name);
     pstmt.setString(2,gruppe);
     pstmt.setString(3,beschr);  
     pstmt.setString(4,std);
     
     pstmt.executeUpdate();

  }/* execPreparedStmt */



/**
  * wertet ResultSet aus und gibt die Ergebnistabelle zurueck
  * @param ResultSet einer SQL-Anweisung
  * @exception SQLException ausgelst bei Fehler in SQL-Statement
  * @return Ergebnis als HTML-Tabelle
  */
  public String outputResultSet(ResultSet rs) throws SQLException {

    /* Ergebnistabelle ausgeben: */
     ResultSetMetaData rsmd = rs.getMetaData();

    /* Wieviele Spalten hat das Ergebnis */
     int columns = rsmd.getColumnCount();
      
     StringBuffer sb=new StringBuffer();		
             
    /* Kopf des HTML-Dokuments */
     sb.append("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD " + "HTML 4.0//EN//\">\n");
     sb.append("<HTML>\n");
     sb.append("<TITLE> Ergebnis Datenbankabfrage</TITLE>\n");
     sb.append("<BODY>\n");
     sb.append("<H1> Resultat </H1>");

    /* Start der Tabelle */
     sb.append("<TABLE BORDER='1'>\n");
     sb.append("<TR VALIGN='top'>\n");

    /* Auswerten der Spaltenueberschriften und oben in die Tabelle schreiben */
      for (int i = 1; i <= columns; i++)
	 sb.append("<TH>" +
	 rsmd.getColumnName(i).toString() +
	 "</TH>\n");
     sb.append("</TR>\n");

     // Tabelleninhalt Zeile fr Zeile ausgeben:
     while (rs.next()){

       sb.append("<TR VALIGN='top'>\n");

       // Zeileninhalt Zelle fr Zelle ausgeben:
       for (int i = 1; i <= columns; i++) {
	  Object o = rs.getObject(i);
	  if (rs.wasNull()) o = new String("NULL");
	  if (o == null) o = new String("*NULL*");
	  sb.append("<TD>" + o.toString() + "</TD>\n");
       }
       sb.append("</TR>\n");
    }
    sb.append("</TABLE>\n");
    sb.append("</BODY>\n");
    sb.append("</HTML>\n");
    rs.close();  

   /* Rueckgabe als String */ 
    return sb.toString();

   }/* outputResultSet() */


/**
  * Schliet die Datenbankverbindung (Connection)
  */
   protected void close()
   {
      ByteArrayOutputStream b = new ByteArrayOutputStream(5000);
      PrintWriter p = new PrintWriter(new OutputStreamWriter(b));
      try
      {
	 con.close();
      }
      catch (Exception ex)
      {
	 p.println("<PRE>");
	 p.println(ex.getMessage());
	 ex.printStackTrace(p);
	 p.println("</PRE>");
      }
      finally
      {
	 con = null;
	 stmt = null;
      }
      p.close();
   
  }/* close() */
   
}/* end Klasse Database */
