import javax.servlet.*;
import javax.servlet.http.*;
import java.io.*;
import java.net.*;
import java.sql.*;
import java.util.*;
import sun.jdbc.odbc.*;
import java.sql.Date;


/**
  * Die Klasse <var>JDBCServlet</var>
  * <p>
  * Das Beispiel ist eng an das Beispiel <var>MonitorServlet</var> aus dem Buch von Rainer Klute, JDBC in der Praxis 
  * angelehnt und enstprechend fr unser Projektstudium angepasst worden.
  * </p>
  * @author Sven Garske und Jrn Hauswald
  * @verison Projektstudium SS98
  */ 



public class JDBCServlet extends HttpServlet
{
  //Fr den Verweis im Formular   
   public final String HOST="http://195.37.85.18:8081/servlet/JDBCServlet"; 

   Connection con;  


/**
  * <p>Initialisieren der Servlet-Instanz, hier: Laden des
  * JDBC-Treibers.</p>
  */
  public void init(ServletConfig config) throws ServletException {

      super.init(config);
     
      String driver = "sun.jdbc.odbc.JdbcOdbcDriver";
      try
      {
	 /* JDBC-Treiber laden: */
	 Class.forName(driver);

         /* Ausgabe das Treiber geladen ist */
	 System.err.println(this.toString() + ": JDBC-Treiber "
                                       + driver + " geladen");

         /* Aufbau der Verbindung zur Datenbank ueber die JDBC-URL */
         String url="jdbc:odbc:ps";
         con=DriverManager.getConnection(url);
                 
      }
      /* Abfangen,wenn Treiber nicht geladen ist oder DB-Connection
         nicht aufgebaut werden konnte */
     
      catch(ClassNotFoundException e)
      {
	 log("JDBC-Treiber "+ driver + " nicht geladen");
         throw new UnavailableException(this,e.getMessage());
      }
      catch (SQLException e2)
      {
         log("Fehler bei DB-Connection "+e2.getMessage());
         throw new UnavailableException(this,e2.getMessage());
      }

  }/* init() */


/**
  * <p>Bearbeiten eines GET-Requests</p>
  * da doGet und doPost dasselbe tun sollen, wird von
  * hier doGetOrPost aufgerufen
  */
  public void doGet (HttpServletRequest req,
		      HttpServletResponse res)
      throws ServletException, IOException
   {
       doGetOrPost (req, res);
   }



/**
  * <p>Bearbeiten eines POST-Requests</p>
  * da doGet und doPost dasselbe tun wird von
  * hier doGetOrPost aufgerufen   
  */
   public void doPost (HttpServletRequest req,
		       HttpServletResponse res)
      throws ServletException, IOException
   {
       doGetOrPost (req, res);
   }



/**
  * <p>GET- und POST-Requests werden auf gleiche Weise
  * bearbeitet.</p>
  * 
  * Folgende Schritte werden durchgefuehrt :
  *  1. Schritt : Auswerten der Parameter
  *  2. Schritt : Ausfuehren der entsprechenden Prozedur 
  */
  private void doGetOrPost (HttpServletRequest req,
			    HttpServletResponse res)
      throws ServletException, IOException
   {
    try {

      /* Parameter auslesen: */

     /** 1. Schritt : Auswerten der gewaehlten Schaltflaeche
       * Welche Schaltflche hat der Benutzer bettigt? 
       */

      res.setStatus(200,"OK");
      res.setContentType("text/html");
      
      String param = req.getParameter("start");
     //Neue Datenbankabfrage     
      if (param != null) {
          log("Starteseite");
          createStartseite(res);
      }

     //Abfrage Gruppen
      param = req.getParameter("AbGr");
      if (param != null) {
          log("Abfrage Gruppen");
          queryAusfuehren(res,"SELECT * FROM gruppen");
      }


     //Abfrage Teilnehmer
      param = req.getParameter("AbTn");
      if (param != null) {
        log("Abfrage Teilnehmer");
        queryAusfuehren(res,"SELECT * FROM teilnehmer");
      }


     //Abfrage Protokolleintrge
      param = req.getParameter("AbPk");
      if (param != null) {
        log("Abfrage Protokolleintrge");
        queryAusfuehren(res,"SELECT * FROM protokoll");   
      }


     //Zufgen Protokolleintrge
     param = req.getParameter("NPE");
     if (param != null) {
        log("Neuer Protokolleintrag");
        createProtokollEintrag(res);   
      }
  
     
     //angezeigte Seite Neuer Protokolleintrag
     param = req.getParameter("Inab");
     if (param != null) {
           res.setStatus(204,"No Content");
           log("Neuer Inab");
           String t=req.getParameter("Tag");
           int tag = java.lang.Integer.parseInt(t); 
           String m=req.getParameter("Monat");
           int monat=java.lang.Integer.parseInt(m);
           String j=req.getParameter("Jahr");
           int jahr=java.lang.Integer.parseInt(j);
           Date datum=new Date((jahr-1900),(monat-1),tag);
           String name=req.getParameter("Name");
           if (name==null) name=" ";
           String gruppe=req.getParameter("Gruppe");
           if (gruppe==null) gruppe=" ";
           String beschr=req.getParameter("Probez");
           if (beschr==null) beschr=" ";
           String std=req.getParameter("Stunden");            
           if (std==null) std="0";

           //Absenden des PreparedStatement
           Database db=new Database(con,datum,name,gruppe,beschr,std);        
           db.execPreparedStmt();  
           //Hier wird kein Ergebnis geliefert,da hier etwas eingefuegt wird
      }

     //Anzeigen der Startseite       
    param = req.getParameter("zurueck");
     if (param != null) {
           log("Zurck zur Startseite");
           createStartseite(res);   
      } 

    }
    catch (SQLException e1){
        throw new ServletException("Abfrage "+e1.getMessage());
    }     
   
    res.getOutputStream().close(); 


   }/* doGetOrPost() */
    


/**
  * Erstellen der Startseite durch Servlet
  */
  public void createStartseite(HttpServletResponse res){

  try {
   ServletOutputStream b=res.getOutputStream();
   PrintWriter out = new PrintWriter(new OutputStreamWriter(b));

   //Kopf der HTML-Ausgabe
   out.println("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD " + "HTML 4.0//EN//\">");
   out.println("<HTML>");
   out.println("<HEAD>");
   out.println("<TITLE> Datenbankabfrage ber ein Servlet </TITLE>");
   out.println("</HEAD>");
   out.println("<BODY>");
   out.println("<H1> Datenbankabfrage ber ein Servlet </H1>");
   out.println("<HR>");
   //Konstante Host
   out.println("<FORM ACTION="+HOST+" METHOD='get'>");

   //Schaltflaechen
   out.println("<TR VALIGN='top'><TD><INPUT TYPE='submit' NAME='NPE' VALUE='Neuer Protokolleintrag'>"+
               "</TD>"+
               "<TD>"+"<INPUT TYPE='submit' NAME='AbGr' VALUE='Abfrage Gruppen'>"+"</TD>"+
               "<TD>"+"<INPUT TYPE='submit' NAME='AbTn' VALUE='Abfrage Teilnehmer'>"+"</TD>"+
               "<TD>"+"<INPUT TYPE='submit' NAME='AbPk' VALUE='Abfrage Protokoll'>"+"</TD>"+
               "</TD></TR>");
   out.println("</FORM>");
   out.println("</BODY>");
   out.println("</HTML>");

   //Ende der HTML-Ausgabe

   //Schliessen des PrintWriter
   out.close();
   
   } 
   catch (IOException e) {
	log(e.toString());
   }

       
}/* createStartseite() */



/**
  * Ausgabe des Ergebnisses der bergebenen SQL-Anweisung
  */
  public void queryAusfuehren(HttpServletResponse res,String sql)
                                throws SQLException {

    try { 

      OutputStream b = res.getOutputStream();
      PrintWriter out = new PrintWriter(new OutputStreamWriter(b));

      //Aufruf der Database mit der SQL-Anweisung
      Database db=new Database(con,sql);
  
    
      /* Ausfuehren der SQL-Anweisung und auswerten der Ergebnis 
         ueber Methoden die Database*/
      out.println(db.outputResultSet(db.execSQL()));
      
      // Schliessen des PrintWriter
      out.close();

     } 
     catch (IOException e) {
       log(e.toString()); 
    }

   }/* queryAusfuehren() */


 
/**
  * Aufbau einer neuen HTML-Seite zum Eingeben eines Eintrages
  * in die Protokoll-Tabelle
  */
  public void createProtokollEintrag(HttpServletResponse res){
  
  try {
   ServletOutputStream b = res.getOutputStream();
   PrintWriter out = new PrintWriter(new OutputStreamWriter(b));

   out.println("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD " + "HTML 4.0//EN//\">");
   out.println("<HTML>");
   out.println("<HEAD>");
   out.println("<TITLE> Datenbankabfrage ber ein Servlet </TITLE>");
   out.println("</HEAD>");
   out.println("<BODY>");
   out.println("<H1> Datenbankabfrage ber ein Servlet </H1>");
   out.println("<HR>");
  //Konstante HOST
   out.println("<FORM ACTION="+HOST+" METHOD='get'>");
   out.println("<TABLE>");
   out.println("<TR VALIGN='top'>");
   out.println("<TD VALIGN='top'>Datum :</TD>");
   out.println("<TD><INPUT SIZE='2' TYPE='text' NAME='Tag' VALUE='2'></TD>");
   out.println("<TD><INPUT SIZE='2' TYPE='text' NAME='Monat' VALUE='7'></TD>");
   out.println("<TD><INPUT SIZE='4' TYPE='text' NAME='Jahr' VALUE='1998'></TD>");
   out.println("</TR><p>");

   out.println("<TR VALIGN='top'>");
   out.println("<TD VALIGN='top'>Name :</TD>");
   out.println("<TD><INPUT SIZE='50' TYPE='text' NAME='Name' VALUE=''></TD>");
   out.println("</TR><p>");
 
   out.println("<TR VALIGN='top'>");
   out.println("<TD VALIGN='top'>Gruppe :</TD>");
   out.println("<TD><INPUT SIZE='50' TYPE='text' NAME='Gruppe' VALUE=''></TD>");
   out.println("</TR><p>");

   out.println("<TR VALIGN='top'>");
   out.println("<TD VALIGN='top'>Protokollbeschreibung :</TD>");
   out.println("<TD><INPUT SIZE='50' TYPE='text' NAME='Probez' VALUE=''></TD>");
   out.println("</TR><p>");

   out.println("<TR VALIGN='top'>");
   out.println("<TD VALIGN='top'>Stundenzahl :</TD>");
   out.println("<TD><INPUT SIZE='5' TYPE='text' NAME='Stunden' VALUE=''></TD>");
   out.println("</TR><p>");

   //Schaltflaechen

   out.println("<TR VALIGN='top'><TD><INPUT TYPE='submit' NAME='Inab' VALUE='Insert abschicken'>"+
               "</TD><TD>"+
               "<INPUT TYPE='reset' NAME='weg' VALUE='Eintrge lschen'>"+
               "<INPUT TYPE='submit' NAME='zurueck' VALUE='zurck zur Abfrageseite'>"+
               "</TD></TR>");
   out.println("</TABLE>");
   out.println("</FORM>");
   out.println("</BODY>");
   out.println("</HTML>");
   out.close();

//   log("Abschu");
   } 
   catch (IOException e) {
       log(e.toString());}

  }/* insertProtokoll() */
                   


}/* end Klasse JDBCServlet */
